@@ -1,6 +1,6 @@
 package Spreadsheet::XLSX::Reader::LibXML::Cell;
 our $AUTHORITY = 'cpan:JANDREW';
-use version; our $VERSION = qv('v0.36.28');
+use version; our $VERSION = qv('v0.38.4');
 
 $| = 1;
 use 5.010;
@@ -119,11 +119,11 @@ has cell_hyperlink =>(
 		predicate	=> 'has_hyperlink',
 	);
 
-has unformatted_converter =>(
-		isa			=> CodeRef,
-		reader		=> '_convert_output',
-		required	=> 1,
-	);
+#~ has unformatted_converter =>(
+		#~ isa			=> CodeRef,
+		#~ reader		=> '_convert_output',
+		#~ required	=> 1,
+	#~ );
 
 has cell_coercion =>(
 		isa			=> HasMethods[ 'assert_coerce', 'display_name' ],
@@ -152,9 +152,6 @@ sub unformatted{
 	# get the value
 	my	$unformatted	= $self->_unformatted;
 	###LogSD	$phone->talk( level => 'debug', message => [ "unformatted:", $unformatted ] );
-	my	$converter = $self->_convert_output;
-	$unformatted = $converter->( $unformatted );
-	###LogSD	$phone->talk( level => 'debug', message => [ "converted:", $unformatted ] );
 	return $unformatted;
 }
 
@@ -231,7 +228,7 @@ sub _return_value_only{
 	my	$formatted = $unformatted;
 	if( !$coercion ){
 		###LogSD	$phone->talk( level => 'debug', message => [
-		###LogSD		"No coercion passed" ) ] );
+		###LogSD		"No coercion passed" ] );
 		return $unformatted;
 	}elsif( !defined $unformatted ){
 		$error_inst->set_error( "The cell does not have a value" );
@@ -295,7 +292,10 @@ This is the class that contains cell data.  There are no XML parsing actions tak
 background of this class.  All data has been pre-coalated/built from the L<Worksheet
 |Spreadsheet::XLSX::Reader::LibXML::Worksheet> class.  In general the Worksheet class 
 will populate the attributes of this class when it is generated.  If you want to use it 
-as a standalone class just fill in the L<Attributes|/Attributes> below.
+as a standalone class just fill in the L<Attributes|/Attributes> below.  It should be 
+noted that the Worksheet class also L<pre-converts
+|Spreadsheet::XLSX::Reader::LibXML::FmtDefault/change_output_encoding( $string )> the 
+unformatted value as well.
 
 =head2 Primary Methods
 
@@ -311,13 +311,11 @@ B<Example:>
 
 =over
 
-B<Definition:> Returns the unformatted value of the cell transformed with the 
-L<change_output_encoding|Spreadsheet::XLSX::Reader::LibXML::FmtDefault/change_output_encoding( $string )> 
-method.
+B<Definition:> Returns the unformatted value of the cell
 
 B<Accepts:>Nothing
 
-B<Returns:> the cell value processed by the encoding conversion
+B<Returns:> the raw cell value
 
 =back
 
